@@ -1,6 +1,9 @@
 from . import symbolic_representation
 from . import chainApproximation
 from . import chainApproximation_c
-from . import caggregation_memview
 from . import digitization
+from . import aggregation_memview
+from . import aggregation
+from . import fabba_agg_memview
+from . import fabba_agg
 from . import load_datasets
